@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_master - remote control master for Nokia N900 phone #
-# $Id: smscon_master.py 186 2012-05-31 19:58:29Z yablacky $
+# $Id: smscon_master.py 196 2012-06-08 18:44:59Z yablacky $
 ##############################################################
 
 import os
@@ -14,12 +14,12 @@ from smsconlib import *
 ##############################################################
 # For help text, assemble pretty display names of our various files:
 
-ScriptDisplayName    = ScriptFile.replace(NAME, '').strip('_')
-ConfigDisplayName    = ConfigFile.replace(NAME, '').strip('_')
-CodeDisplayName      = CodeFile  .replace(NAME, '').strip('_')
-BootDisplayName      = BootFile  .replace(NAME, '').strip('_')
-ScriptLogDisplayName = ScriptLog .replace(NAME, '').strip('_')
-LogDisplayName       = LogFile   .replace(NAME, '').strip('_')
+ScriptDisplayName    = ScriptFile.replace(NAME, '').strip('_') or 'script'
+ConfigDisplayName    = ConfigFile.replace(NAME, '').strip('_') or 'config'
+CodeDisplayName      = CodeFile  .replace(NAME, '').strip('_') or 'code'
+BootDisplayName      = BootFile  .replace(NAME, '').strip('_') or 'boot'
+ScriptLogDisplayName = ScriptLog .replace(NAME, '').strip('_') or 'log'
+LogDisplayName       = LogFile   .replace(NAME, '').strip('_') or 'log'
 
 ##############################################################
 
