@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_service - remote control daemon for Nokia N900 phone#
-# $Id: smscon_service.py 193 2012-06-05 23:07:49Z yablacky $
+# $Id: smscon_service.py 197 2012-06-08 18:51:08Z yablacky $
 ##############################################################
 
 # standard modules
@@ -824,8 +824,9 @@ def PerformShellScript(args = []):
     # run script file
     try:
         os.system( '"%s" %s 1>>"%s" 2>&1&' % (Filename, ' '.join([shellArg(a) for a in args]), Logname) )
-        LOGGER.info(         'Script %s executes in BG.' % str(args))
-        RevealThat('script', 'Script %s executes in BG.' % str(args))
+        PIDs = pidof(Filename)
+        LOGGER.info(         'Script %s executes in BG [PIDs=%s].' % (str(args), PIDs))
+        RevealThat('script', 'Script %s executes in BG [PIDs=%s].' % (str(args), PIDs))
     except Exception, e:
         LOGGER.error('Failed to execute script %s: %s' % (str(args), e))
         RevealThat('shell', ['Failed to execute script %s.' % str(args)])        
@@ -838,10 +839,11 @@ def PerformShellScriptResult():
     Filename = os.path.join(InstPath, smscon.ScriptFile)
     Logname  = os.path.join(InstPath, smscon.ScriptLog)
     PIDs = pidof(Filename)
+    ScriptRunInfo = IF(PIDs, 'Scripts are running [PIDs=%s].' % PIDs, 'No scripts running.')
     if not IsFileReadable(Logname):
-        RevealThat('script.log', 'Log file %s not present. Script processes running: (%s).' % (Logname, PIDs))
+        RevealThat('script.log', 'Log file %s not present. %s' % (Logname, ScriptRunInfo))
     else:
-        RevealThat('script.log', 'Log file %s is attached. Script processes running: (%s).' % (Logname, PIDs),
+        RevealThat('script.log', 'Log file %s is attached. %s' % (Logname, ScriptRunInfo),
                    Attachment = Logname, Attachhint = 'text/plain')
 
 def PerformDirectShellCommand(Command):
@@ -1812,20 +1814,35 @@ def ValidateIMSI():
     """
     Check if current used IMSI code from SIM card is authorized.
     """
+    def HandleIMSIValidation(IsAuthorizedSIM = False, CurrentIMSI = None):
+        """
+        Perform actions depending on IMSI validation status.
+        @param bool IsAuthorizedSIM Whether or not the current SIM was a known one.
+        @return string Device lock status
+        """
+        # Use silent calls to lock/unlock and RevealThat situation once only:
+        DeviceLockStatus = ''
+        if smscnf.SIMUNLOCK == 'lockalways':
+            DeviceLockStatus = __DoDeviceLock() + ' Lock always was enabled.'
+        elif IsAuthorizedSIM:
+            pass
+        elif smscnf.SIMUNLOCK == 'locknewsim':
+            DeviceLockStatus = __DoDeviceLock() 
+        elif smscnf.SIMUNLOCK == 'yes':
+            DeviceLockStatus = __DoDeviceUnlock() 
+
+        if not IsAuthorizedSIM:
+            # TO DO: emit signal
+            pass
+        
+        return DeviceLockStatus
+    
     KnownIMSICodes = ReadIMSI();
     CurrentIMSI = smscon.GetPhoneCode('IMSI')
-    DeviceLockStatus = 'Phone lock status unchanged.'
 
     if CurrentIMSI == None:
-        # Use silent calls to lock/unlock and RevealThat situation once only:
-        if smscnf.SIMUNLOCK == 'yes':
-            DeviceLockStatus = __DoDeviceUnlock() + ' Because unlock if no SIM.'
-        elif smscnf.SIMUNLOCK == 'locknewsim':
-            DeviceLockStatus = __DoDeviceLock() + ' Because lock if no SIM.'
-        elif smscnf.SIMUNLOCK == 'lockalways':
-            DeviceLockStatus = __DoDeviceLock() + ' Because lock always.'
-
-        LOGGER.warning( 'SIM card not present or inactive. %s' % (CurrentIMSI, DeviceLockStatus))
+        DeviceLockStatus = HandleIMSIValidation(IsAuthorizedSIM = False, CurrentIMSI = CurrentIMSI)
+        LOGGER.warning( 'SIM card not present or inactive. %s' % DeviceLockStatus)
 
         # With some luck internet connection via wlan is available.
         SendMethod = 'email'    # sms would not work w/o a SIM...
@@ -1835,19 +1852,11 @@ def ValidateIMSI():
                         SendMethod)
 
     elif CurrentIMSI in KnownIMSICodes:
-        LOGGER.info('SIM card with authorized IMSI code "%s" detected.' % CurrentIMSI)
-        if smscnf.SIMUNLOCK == 'lockalways':
-            PerformDeviceLock(' Because lock always.') 
+        DeviceLockStatus = HandleIMSIValidation(IsAuthorizedSIM = True, CurrentIMSI = CurrentIMSI)
+        LOGGER.info('SIM card is authorized by IMSI code "%s". %s' % (CurrentIMSI, DeviceLockStatus))
 
     else:
-        # Use silent calls to lock/unlock and RevealThat situation once only:
-        if smscnf.SIMUNLOCK == 'yes':
-            DeviceLockStatus = __DoDeviceUnlock() + ' Because unlock if new SIM.'
-        elif smscnf.SIMUNLOCK == 'locknewsim':
-            DeviceLockStatus = __DoDeviceLock() + ' Because lock if new SIM.'
-        elif smscnf.SIMUNLOCK == 'lockalways':
-            DeviceLockStatus = __DoDeviceLock() + ' Because lock always.'
-
+        DeviceLockStatus = HandleIMSIValidation(IsAuthorizedSIM = False, CurrentIMSI = CurrentIMSI)
         LOGGER.warning('SIM card not yet autorized. New IMSI code is "%s". %s' % (CurrentIMSI, DeviceLockStatus))
 
         SendMethod = smscnf.MESSAGESEND
@@ -1969,6 +1978,7 @@ def DoCommandLine(args):
             LOGGER.warning('Simulating received SMS message from MASTERNUMBER with "%s" command.' % Command)
             ProcessCommand(Command, SenderPhoneNumber = smscnf.MASTERNUMBER,
                            ExtraInfo = 'SIMULATION!', CommandOrigin = 'CMDLINE', LogIfCmdUnknown = True)    
+
         elif Mode == '-sendemail':
             if len(args) < 3 : return TellError('%s requires at least 3 arguments.' % Mode)
             Recipient, Subject, Text = args.pop(0), args.pop(0), args.pop(0)
@@ -1985,6 +1995,7 @@ def DoCommandLine(args):
         else:
             LOGGER.warning('Option error (%s) - ignored' % Mode)
             return CommandLineStatus
+
     if len(args) > 0:
         LOGGER.warning('Options ignored: %s' % ' '.join(args))
     return CommandLineStatus
@@ -1996,20 +2007,20 @@ def CheckBootLoader(WithNotification = True):
     Check if smscon auto-loads at system boot.
     @return void.
     """
-    if IsFileReadable(smscon.BootPath, smscon.BootFile):
+    if smscon.IsBootfileExistent():
         LOGGER.info('%s auto-loads at boot. OK. %s' % (smscon.NAME, IF(WithNotification, '', 'Silent check.')))
     else:
         LOGGER.warning("%s does not auto-load at boot. %s" % (smscon.NAME, IF(WithNotification, '', 'Silent check.')))
         if WithNotification:
             RevealThat('boot', "%s does not auto-load at boot." % smscon.NAME)        
 
-def ExitDaemon(ExitReason = 'regularly'):
+def ExitDaemon(ExitReason = 'regularly', ExitCode = 0):
     """
     Exit smscon_daemon.
     @return NO RETURN.
     """
     LOGGER.critical('%s is stopping %s.' % (DaemonFile, ExitReason))
-    sys.exit(1)
+    sys.exit(ExitCode)
 
 def RestartDaemon():
     """
@@ -2337,7 +2348,7 @@ def main():
     signal.signal(smscon.smscon_daemon.TELL_COMMAND,
                     lambda signum, stack_frame: gobject.idle_add(OnLocalCommandAvailable) )
     
-    LoadConfiguration() or ExitDaemon('on config load error')
+    LoadConfiguration() or ExitDaemon('on config load error', ExitCode = 1)
     ValidateIMSI()
     
     # Connect to various signal triggers:
@@ -2370,9 +2381,14 @@ def main():
 
         ApplyConfiguration()
 
-        CommandLineStatus = DoCommandLine(sys.argv[1:])
+        # Now that we behave like a system job, take command from environment: 
+        cliArgs = [os.getenv('CLIMODE', ''), os.getenv('CLIFUNCTION', '')]
+        if cliArgs == ['', ''] : cliArgs = []
+        cliArgs += sys.argv[1:]
+        
+        CommandLineStatus = DoCommandLine(cliArgs)
         if not CommandLineStatus:
-            ExitDaemon('bad command line')
+            ExitDaemon('bad command line', ExitCode = 1)
 
         InstallSignalReceivers()
 
