@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon - remote control library for Nokia N900 phone       #
-# $Id: smsconlib.py 192 2012-06-05 23:01:07Z yablacky $
+# $Id: smsconlib.py 198 2012-06-08 18:52:49Z yablacky $
 ##############################################################
 
 # standard modules
@@ -34,7 +34,7 @@ NAME = 'smscon'
 VERSION = '999.1'   # for trunk and private builds etc.
 
 NAME, VERSION = getSysBuildNameAndVersion(NAME, VERSION,
-    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.10.2/src/opt/smscon/smsconlib.py 192 2012-06-05 23:01:07Z yablacky $',
+    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.10.3/src/opt/smscon/smsconlib.py 198 2012-06-08 18:52:49Z yablacky $',
     dirLevels   = 3 )
     
 XDEBUG   = False        # cross debug (use only if not running on phone)
@@ -44,14 +44,14 @@ XDEBUG   = False        # cross debug (use only if not running on phone)
 TimeFormat  = '%Y-%m-%d %H:%M:%S'
 InstPath    = '/opt/%s' % NAME
 if XDEBUG: InstPath = '.'
-BootPath    = '/etc/event.d'
 DaemonFile  = '%s_daemon' % NAME
 CommandFile = '%s_cmds' % NAME
 CodeFile    = '%s_code' % NAME
 ConfigFile  = '%s_config' % NAME
-BootFile    = '%s_boot' % NAME
 ScriptFile  = '%s_script' % NAME
 ScriptLog   = '%s_script.log' % NAME
+BootPath    = '/etc/event.d'
+BootFile    = '%s' % NAME       # This will be the system wide job name.
 
 PhotoName   = 'frontcam.jpg'
 MapName     = 'gpsmap.png'
@@ -950,9 +950,9 @@ class smscon_daemon:
     """
     Instances of this class are used to control the smscon daemon.
     """
-    TELL_RELOAD    = signal.SIGINT
+    TELL_RELOAD    = signal.SIGHUP
     TELL_TERMINATE = signal.SIGTERM
-    TELL_COMMAND   = signal.SIGHUP
+    TELL_COMMAND   = signal.SIGINT
     _cmdPrefix     = '<cmd>'
     _cmdSuffix     = '</cmd>'
 
@@ -974,16 +974,37 @@ class smscon_daemon:
         Start new smscon_daemon instance (even if some daemon instances already run).
         @return void.
         """
-        DaemonArgs = IF(Mode or Function, ' %s %s' % (shellArg(Mode or ''), shellArg(Function or '')), '')
-        os.system( '"%s"%s&' % (os.path.join(InstPath, DaemonFile), DaemonArgs))
-        LOGGER.info('Daemon %s requested to start%s.' % (DaemonFile, DaemonArgs))
+        Mode = Mode or ''
+        Function = Function or ''
+        DaemonArgs = ''
+        if Mode or Function:
+            DaemonArgs = 'CLIMODE=%s CLIFUNCTION=%s' % (shellArg(Mode), shellArg(Function))
+
+        if IsBootfileExistent():
+#            if Mode or Function:
+#                DaemonArgs = shellArg('CLIMODE=' + Mode) + ' ' + shellArg('CLIFUNCTION=' + Function)
+#            os.system('/sbin/initctl --quiet start %s %s' % (NAME, DaemonArgs))
+            # --- Above code won't work with initctl version 0.3.8 because it didn't pass environment
+            # variables to the started job.  Neither by passing them as command arg nor by setting
+            # them up in callers environment :-( Workaround: start and pass command via command channel:
+            os.system('/sbin/initctl --quiet start %s' % BootFile)
+            if Mode or Function:
+                time.sleep(2)
+                self.writeCliCommand(Mode, Function)
+        else:
+            os.system('%s "%s"&' % (DaemonArgs, os.path.join(InstPath, DaemonFile)))
+        LOGGER.info('Daemon %s requested to start%s.' % (DaemonFile, IF(Mode or Function,' '+Mode+' '+Function,'')))
     
     def stop(self):
         """
         Kill all smscon_daemon(s).
         @return: string with PIDs of daemons stopped. Empty if none were running.
         """
-        PIDs = self.tell(self.TELL_TERMINATE)
+        if IsBootfileExistent():
+            PIDs = self.runs()
+            os.system('/sbin/initctl --quiet stop %s' % BootFile)
+        else:
+            PIDs = self.tell(self.TELL_TERMINATE)
         if PIDs:
             LOGGER.info('Daemon %s stopped [PID=%s].' % (DaemonFile, PIDs) )
         else:
@@ -1288,26 +1309,42 @@ netstat -tean
 
 ##############################################################
 
+def IsBootfileExistent():
+    """
+    @return bool True iff a BootFile exists and is readable.
+    """
+    return IsFileReadable(os.path.join(BootPath, BootFile))
+
 def CreateBootfile():
     """
-    Set start smscon_daemon at device boot.
+    Setup to start smscon_daemon at device boot.
     @return bool True iff a BootFile exists or could be created.
     """
-    BootCode = 'description "%s %s - nokia n900 remote control utility"\n' % (NAME, VERSION) + \
-"""
+    BootCode = """\
+description "%(NAME)s - nokia n900 remote control utility"
+author "Lutz Schwarz, Frank Visser"
+version "%(VERSION)s"
+
 start on started hildon-desktop
 stop on starting shutdown
 
 console none
 
-script
-    while [ ! -e "%s" ]; do
+pre-start script
+    while [ ! -e "%(InstPath)s" ]; do
         sleep 3
     done
-    exec "%s" -start > "%s" 2>&1
 end script
 
-""" % (InstPath, os.path.join(InstPath, NAME), os.path.join(InstPath, NAME+'_boot.log'))
+script                                                           
+    exec "%(DaemonFile)s" > "%(LogFile)s" 2>&1
+end script 
+
+respawn
+""" % {'NAME': NAME, 'VERSION': VERSION, 'InstPath': InstPath,
+       'DaemonFile' : os.path.join(InstPath, DaemonFile),
+       'LogFile'    : os.path.join(InstPath, NAME+'_boot.log')
+       }
 
     Filename = os.path.join(BootPath, BootFile)
     if IsFileReadable(Filename):
